﻿/**
 * @name umi 的路由配置
 * @description 只支持 path,component,routes,redirect,wrappers,name,icon 的配置
 * @param path  path 只支持两种占位符配置，第一种是动态参数 :id 的形式，第二种是 * 通配符，通配符只能出现路由字符串的最后。
 * @param component 配置 location 和 path 匹配后用于渲染的 React 组件路径。可以是绝对路径，也可以是相对路径，如果是相对路径，会从 src/pages 开始找起。
 * @param routes 配置子路由，通常在需要为多个路径增加 layout 组件时使用。
 * @param redirect 配置路由跳转
 * @param wrappers 配置路由组件的包装组件，通过包装组件可以为当前的路由组件组合进更多的功能。 比如，可以用于路由级别的权限校验
 * @param name 配置路由的标题，默认读取国际化文件 menu.ts 中 menu.xxxx 的值，如配置 name 为 login，则读取 menu.ts 中 menu.login 的取值作为标题
 * @param icon 配置路由的图标，取值参考 https://ant.design/components/icon-cn， 注意去除风格后缀和大小写，如想要配置图标为 <StepBackwardOutlined /> 则取值应为 stepBackward 或 StepBackward，如想要配置图标为 <UserOutlined /> 则取值应为 user 或者 User
 * @doc https://umijs.org/docs/guides/routes
 */
const newMenu = [
  // 分销商页面
  {
    path: '/distributor',
    redirect: '/distributor/wxMiniApp',
  },
  {
    name: 'distributor.account',
    icon: 'icon-zhanghaoguanli',
    path: '/distributor/account',
    access: "isShow",
    component: './Distributor/Account',
  },
  {
    name: 'distributor.wxMiniApp',
    icon: 'icon-weixin',
    path: '/distributor/wxMiniApp',
    access: "isShow",
    component: './Distributor/WxMiniApp',
  },
  {
    name: 'distributor.dyMiniApp',
    icon: 'icon-douyinzhanghao',
    path: '/distributor/dyMiniApp',
    access: "isShow",
    component: './Distributor/DyMiniApp',
  },
  // 小程序页面
  {
    path: '/miniApp',
    redirect: '/miniApp/book',
  },
  // 小说管理
  {
    path: '/miniApp/book',
    name: 'miniApp.book',
    icon: 'icon-xiaoshuo-wx',
    access: 'isShow',
    routes: [
      {
        path: '/miniApp/book',
        redirect: '/miniApp/book/short',
      },
      {
        path: '/miniApp/book/short',
        name: "short",
        component: './MiniApp/BookManage/Short',
      },
      {
        path: '/miniApp/book/long',
        name: 'long',
        component: './MiniApp/BookManage/Long',
      },
    ],
  },
  // 阅读记录
  {
    path: '/miniApp/readLog',
    name: 'miniApp.readLog',
    icon: 'icon-yuedu-2-wx',
    access: 'isShow',
    routes: [
      {
        path: '/miniApp/readLog',
        redirect: '/miniApp/readLog/short',
      },
      {
        path: '/miniApp/readLog/short',
        name: "short",
        component: './MiniApp/ReadLog/Short',
      },
      {
        path: '/miniApp/readLog/long',
        name: 'long',
        component: './MiniApp/ReadLog/Long',
      },
    ],
  },
  // 充值记录
  {
    path: '/miniApp/payLog',
    name: 'miniApp.payLog',
    icon: 'icon-chongzhi01-wx',
    access: 'isShow',
    routes: [
      {
        path: '/miniApp/payLog',
        redirect: '/miniApp/payLog/short',
      },
      {
        path: '/miniApp/payLog/short',
        name: "short",
        component: './MiniApp/PayLog/Short',
      },
      {
        path: '/miniApp/payLog/long',
        name: 'long',
        component: './MiniApp/PayLog/Long',
      },
    ],
  },
  // 消费订单管理
  {
    name: 'miniApp.consume',
    icon: 'icon-xiaofei-wx',
    path: '/miniApp/consume',
    access: "isShow",
    component: './MiniApp/Consume',
  },
  // 小程序端管理
  {
    name: 'miniApp.appManage',
    icon: 'icon-xiaochengxu-wx',
    path: '/miniApp/moduleConfig',
    access: "isShow",
    component: './Admin',
  },
  // 书币充值模板
  {
    name: 'miniApp.payModuleConfig',
    icon: 'icon-taojinbi-wx',
    path: '/miniApp/payModuleConfig',
    access: "isShow",
    component: './MiniApp/ModuleConfig',
  },
]
export default [
  {
    path: '/user',
    layout: false,
    routes: [
      {
        name: 'login',
        path: '/user/login',
        component: './User/Login',
      },
    ],
  },
  {
    path: '/',
    redirect: '/distributor/wxMiniApp',
  },
  {
    path: '*',
    layout: false,
    component: './404',
  },
  ...newMenu
];
